.. slims_lisp documentation master file, created by
   sphinx-quickstart on Thu Jan 23 15:09:43 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

===================================
A high-level CLI for SLIMS REST API
===================================

.. image:: https://img.shields.io/badge/license-apache2-brightgreen.svg
   :target: https://github.com/auwerxlab/slims-lisp-python-api/blob/master/LICENSE

.. image:: https://img.shields.io/github/v/release/auwerxlab/slims-lisp-python-api
   :target: https://github.com/auwerxlab/slims-lisp-python-api/releases

.. image:: https://img.shields.io/pypi/v/slims-lisp
   :target: https://pypi.python.org/pypi/slims-lisp

.. image:: https://readthedocs.org/projects/slims-lisp-python-api/badge/?version=latest
   :target: https://slims-lisp-python-api.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

Documentation
=============

.. toctree::
   :maxdepth: 3

   cli
   modules
   slims_requirements

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
